==> abi-0.7.9.tar.gz: abi-0.7.9/src/wp/ap/xp/ap_Menu_LabelSet_fi-FI.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Finnish translations provided by Jarmo Karvonen <jarmo@dawn.joensuu.fi>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(fi,FI,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Tiedosto",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Uusi", 			"Luo uusi asiakirja")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&Avaa",			"Avaa asiakirja")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Sulje", 			"Sulje asiakirja")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Tallenna", 			"Tallenna asiakirja")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Tallenna &Nimell", 		"Tallenna ksiteltv asiakirja eri nimelle")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"S&ivun asetukset",		"Muuta sivun tulostus asetuksia")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"T&ulosta",			"Tulosta koko asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Lopeta", 			"Sulje kaikki ikkunat ja sulje sovellus")

	MenuLabel(AP_MENU_ID_EDIT,				"&Muokkaa",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Peru",			"Peru muutokset")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Uudelleen",			"Palauta edellinen peruttu muokkaus")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Leikkaa",				"Leikkaa valinta ja sioita se leikepydlle")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Kopioi",			"Kopioi valinta ja sioita se leikepydlle")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"L&iit",			"Liit leikepydn sislt")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Tyhjenn",			"Tyhjenn valinta")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"&Valitse kaikki",		"Valitse koko asiakirja")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Etsi",			"Etsi haluttu teksti")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"K&orvaa",			"Korvaa haluttu teksti toisella tekstill")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&Mene",			"Siirr osoitin haluttuun kohtaan")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Nyt",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Tykalurivit",		NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Perusvalikko",		"Nyt tai piilota perusvalikko")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Muotoilu",		"Nyt tai piilota muotoiluvalikot")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Viivain",			"Nyt tai piilota viivain")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"T&ilapalkki",		"Nyt tai piilota tilapalkki")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"&Nyt koodit",	"Nyt tulostumattomat merkit")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Yltunniste ja alatunniste",	"Muokkaa yl- tai alatunnistetta")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zoomaus",			"Pienenn tai suurenna asiakirjaa nytll")

	MenuLabel(AP_MENU_ID_INSERT,			"&Lis",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Vli",			"Lis sivu, palsta tai kappale vli")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Sivu &Numerot",	"Lis pivittyv sivunumerointi")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"&Pivys ja aika",	"Lis pivys ja/tai aika")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Kentt",			"Lis laskentakentt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Symboli",			"Lis symboli tai muu erikoismerkki")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"K&uva",			"Lis kuva tiedostosta")

	MenuLabel(AP_MENU_ID_FORMAT,			"&Muotoile",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Fontti",			"Muuta Fonttia valitussa tekstiss")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"Ka&ppale",		"Muuta asetuksia valitussa kappaleessa")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"L&uettelomerkit ja numerointi",	"Lis tai moukkaa luettelomerkkej tai numerointia valitussa kappaleessa")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"&Reunat ja varjostus",		"Lis reunat ja varjostus valittuun tekstiin")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Palstat",			"Muuta palstojen mr")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"T&yyli",			"Mrit tai valitse tyyli valittuun tekstiin")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Sisenn",			"Mrit sisennyskohdat")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Lihavoitu",			"Muuta valinta lihavoiduksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursivoitu",			"Muuta valinta kursivoiduksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Alleviivattu",		"Muuta valinta alleviivatuksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,              "Ylle&viivattu",            "Muuta valinta ylleviivaus (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Yliviivattu",			"Muuta valinta yliviivatuksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,   	"Yl&indeksi",         		"Muuta valinta ylindeksiksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,             "Alai&ndeksi",         		"Muuta valinta alaindeksiksi (plle/pois)")
	MenuLabel(AP_MENU_ID_TOOLS,                             "&Tykalut",                       NULL)
        MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Oikoluku",		        "Tarkista asiakirja virheellisit sanoista")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,   "&Laske sanat",          "Lasketaan sanat asiakirjassa")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Asetukset",			"Muuta asetuksia")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Tasaus",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vasen",			"Vasemmalle tasattu kappale")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Keskit",			"Keskita kappale")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Oikea",			"Oikealle tasattu kappale")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Tasaa molemmat reunat",			"Tasaa molemmat reunat")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Ikkuna",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Uusi ikkuna",		"Avaa ikkuna uudelle asiakirjalle")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Lis ikkunoita",	"Nyt koko lista ikkunoista")

	MenuLabel(AP_MENU_ID_HELP,				"&Ohje",			NULL)
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Tietoja %s",		"Kertoo listietoja ohjelmasta, sen versiosta ja kopiointi oikeuksista")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,   "&Ohita kaikki",          "Ohita kaikki tmn sana esiintymiset tss asiakirjassa")
        MenuLabel(AP_MENU_ID_SPELL_ADD,                 "&Lis",                         "Lis tm sana omaan sanastoon")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_Menu_LabelSet_fi-FI.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Finnish translations provided by Jarmo Karvonen <jarmo@dawn.joensuu.fi>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(fi,FI,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Tiedosto",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Uusi", 			"Luo uusi asiakirja")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&Avaa",			"Avaa asiakirja")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Sulje", 			"Sulje asiakirja")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Tallenna", 			"Tallenna asiakirja")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Tallenna &Nimell", 		"Tallenna ksiteltv asiakirja eri nimelle")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"S&ivun asetukset",		"Muuta sivun tulostus asetuksia")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"T&ulosta",			"Tulosta koko asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Avaa tm asiakirja")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Lopeta", 			"Sulje kaikki ikkunat ja sulje sovellus")

	MenuLabel(AP_MENU_ID_EDIT,				"&Muokkaa",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Peru",			"Peru muutokset")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Uudelleen",			"Palauta edellinen peruttu muokkaus")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Leikkaa",				"Leikkaa valinta ja sioita se leikepydlle")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Kopioi",			"Kopioi valinta ja sioita se leikepydlle")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"L&iit",			"Liit leikepydn sislt")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Tyhjenn",			"Tyhjenn valinta")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"&Valitse kaikki",		"Valitse koko asiakirja")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Etsi",			"Etsi haluttu teksti")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"K&orvaa",			"Korvaa haluttu teksti toisella tekstill")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&Mene",			"Siirr osoitin haluttuun kohtaan")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Nyt",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Tykalurivit",		NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Perusvalikko",		"Nyt tai piilota perusvalikko")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Muotoilu",		"Nyt tai piilota muotoiluvalikot")
        MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,             "&Extra",                       "Nyt tai piilota extra tykalut")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Viivain",			"Nyt tai piilota viivain")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"T&ilapalkki",		"Nyt tai piilota tilapalkki")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"&Nyt koodit",	"Nyt tulostumattomat merkit")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Yltunniste ja alatunniste",	"Muokkaa yl- tai alatunnistetta")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zoomaus",			"Pienenn tai suurenna asiakirjaa nytll")

	MenuLabel(AP_MENU_ID_INSERT,			"&Lis",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Vli",			"Lis sivu, palsta tai kappale vli")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Sivu &Numerot",	"Lis pivittyv sivunumerointi")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"&Pivys ja aika",	"Lis pivys ja/tai aika")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Kentt",			"Lis laskentakentt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Symboli",			"Lis symboli tai muu erikoismerkki")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"K&uva",			"Lis kuva tiedostosta")

	MenuLabel(AP_MENU_ID_FORMAT,			"&Muotoile",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Fontti",			"Muuta Fonttia valitussa tekstiss")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"Ka&ppale",		"Muuta asetuksia valitussa kappaleessa")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"L&uettelomerkit ja numerointi",	"Lis tai moukkaa luettelomerkkej tai numerointia valitussa kappaleessa")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"&Reunat ja varjostus",		"Lis reunat ja varjostus valittuun tekstiin")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Palstat",			"Muuta palstojen mr")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"T&yyli",			"Mrit tai valitse tyyli valittuun tekstiin")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Sisenn",			"Mrit sisennyskohdat")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Lihavoitu",			"Muuta valinta lihavoiduksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursivoitu",			"Muuta valinta kursivoiduksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Alleviivattu",		"Muuta valinta alleviivatuksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,              "Ylle&viivattu",            "Muuta valinta ylleviivaus (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Yliviivattu",			"Muuta valinta yliviivatuksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,   	"Yl&indeksi",         		"Muuta valinta ylindeksiksi (plle/pois)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,             "Alai&ndeksi",         		"Muuta valinta alaindeksiksi (plle/pois)")
	MenuLabel(AP_MENU_ID_TOOLS,                             "&Tykalut",                       NULL)
        MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Oikoluku",		        "Tarkista asiakirja virheellisit sanoista")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,   "&Laske sanat",          "Lasketaan sanat asiakirjassa")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Asetukset",			"Muuta asetuksia")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Tasaus",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vasen",			"Vasemmalle tasattu kappale")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Keskit",			"Keskita kappale")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Oikea",			"Oikealle tasattu kappale")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Tasaa molemmat reunat",			"Tasaa molemmat reunat")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Ikkuna",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Uusi ikkuna",		"Avaa ikkuna uudelle asiakirjalle")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Nosta tm ikkuna")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Lis ikkunoita",	"Koko lista ikkunoista")

	MenuLabel(AP_MENU_ID_HELP,				"&Ohje",			NULL)
	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"Ohje &hakemisto",	"Ohjeen hakemiston")
        MenuLabel(AP_MENU_ID_HELP_INDEX,                "Ohjeen &indeksi",          "Ohjeen indeksi")
        MenuLabel(AP_MENU_ID_HELP_CHECKVER,             "Tarkista &Versio",       "Ohjelman versio numero")
        MenuLabel(AP_MENU_ID_HELP_SEARCH,               "&Etsi ohjeesta",       "Etsii hakusanalla ohjeesta")
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Tietoja %s",		"Kertoo listietoja ohjelmasta, sen versiosta ja kopiointi oikeuksista")
        MenuLabel(AP_MENU_ID_HELP_ABOUTOS,              "Tietoja &Open Source",   "Tietoja Open Sourcesta")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,   "%s",                           "Vaihda ehdotettu sana")
        MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,   "&Ohita kaikki",          "Ohita kaikki tmn sana esiintymiset tss asiakirjassa")
        MenuLabel(AP_MENU_ID_SPELL_ADD,                 "&Lis",                         "Lis tm sana omaan sanastoon")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()
